# MonsterUI


<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

## Installation

To install this library, uses

`pip install MonsterUI`

## Getting Started

To get started, check out:

1.  Start by importing the modules as follows:

``` python
from fasthtml.common import *
from monsterui.all import *
```

2.  Instantiate the app with the MonsterUI headers

``` python
app = FastHTML(hdrs=Theme.blue.headers())

# Alternatively, using the fast_app method
app, rt = fast_app(hdrs=Theme.slate.headers())
```

> *The color option can be any of the theme options available out of the
> box*

From here, you can explore the API Reference & examples to see how to
implement the components. You can also check out these demo videos to as
a quick start guide:

- MonsterUI [documentation page and Tutorial
  app](https://monsterui.answer.ai/tutorial_app)
- This
  [video](https://www.loom.com/share/0916e8a95d524c43a4d100ee85157624?sid=9be07e55-c962-4dbd-978c-aa6a0bcee7b3)
  where Isaac iteratively builds a form in 5 minutes with the framework

More resources and improvements to the documentation will be added here
soon!

## LLM context files

Using LLMs for development is a best practice way to get started and
explore. While LLMs cannot code for you, they can be helpful assistants.
You must check, refactor, test, and vet any code any LLM generates for
you - but they are helpful productivity tools.

- [llms.txt](https://raw.githubusercontent.com/AnswerDotAI/monsterui/refs/heads/main/nbs/llms.txt):
  Links to the neccesary reference documents to use the MonsterUI
  library effectively. Contains very little information directly in the
  document.
- [llms-ctx.txt](https://raw.githubusercontent.com/AnswerDotAI/monsterui/refs/heads/main/nbs/llms-ctx.txt):
  MonsterUI specific context only (does not include FastHTML specific
  context)
- [llm-ctx-full.txt](https://raw.githubusercontent.com/AnswerDotAI/monsterui/refs/heads/main/nbs/llms-ctx-full.txt):
  All inclusive FastHTML + MonsterUI context
